/* A Bison parser, made from /home/RobertC/src/cygwin/setup/iniparse.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_INIPARSE_HH
# define BISON_INIPARSE_HH

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     STRING = 258,
     SETUP_TIMESTAMP = 259,
     SETUP_VERSION = 260,
     PACKAGEVERSION = 261,
     INSTALL = 262,
     SOURCE = 263,
     SDESC = 264,
     LDESC = 265,
     CATEGORY = 266,
     DEPENDS = 267,
     REQUIRES = 268,
     APATH = 269,
     PPATH = 270,
     INCLUDE_SETUP = 271,
     EXCLUDE_PACKAGE = 272,
     DOWNLOAD_URL = 273,
     T_PREV = 274,
     T_CURR = 275,
     T_TEST = 276,
     MD5 = 277,
     INSTALLEDSIZE = 278,
     MAINTAINER = 279,
     PRIORITY = 280,
     DESCTAG = 281,
     DESCRIPTION = 282,
     FILESIZE = 283,
     ARCHITECTURE = 284,
     SOURCEPACKAGE = 285,
     MD5LINE = 286,
     RECOMMENDS = 287,
     PREDEPENDS = 288,
     SUGGESTS = 289,
     CONFLICTS = 290,
     REPLACES = 291,
     PROVIDES = 292,
     PACKAGENAME = 293,
     STRTOEOL = 294,
     PARAGRAPH = 295,
     EMAIL = 296,
     COMMA = 297,
     OR = 298,
     NL = 299,
     AT = 300,
     OPENBRACE = 301,
     CLOSEBRACE = 302,
     EQUAL = 303,
     GT = 304,
     LT = 305,
     GTEQUAL = 306,
     LTEQUAL = 307,
     OPENSQUARE = 308,
     CLOSESQUARE = 309,
     BINARYPACKAGE = 310,
     BUILDDEPENDS = 311,
     STANDARDSVERSION = 312,
     FORMAT = 313,
     DIRECTORY = 314,
     FILES = 315
   };
#endif
#define STRING 258
#define SETUP_TIMESTAMP 259
#define SETUP_VERSION 260
#define PACKAGEVERSION 261
#define INSTALL 262
#define SOURCE 263
#define SDESC 264
#define LDESC 265
#define CATEGORY 266
#define DEPENDS 267
#define REQUIRES 268
#define APATH 269
#define PPATH 270
#define INCLUDE_SETUP 271
#define EXCLUDE_PACKAGE 272
#define DOWNLOAD_URL 273
#define T_PREV 274
#define T_CURR 275
#define T_TEST 276
#define MD5 277
#define INSTALLEDSIZE 278
#define MAINTAINER 279
#define PRIORITY 280
#define DESCTAG 281
#define DESCRIPTION 282
#define FILESIZE 283
#define ARCHITECTURE 284
#define SOURCEPACKAGE 285
#define MD5LINE 286
#define RECOMMENDS 287
#define PREDEPENDS 288
#define SUGGESTS 289
#define CONFLICTS 290
#define REPLACES 291
#define PROVIDES 292
#define PACKAGENAME 293
#define STRTOEOL 294
#define PARAGRAPH 295
#define EMAIL 296
#define COMMA 297
#define OR 298
#define NL 299
#define AT 300
#define OPENBRACE 301
#define CLOSEBRACE 302
#define EQUAL 303
#define GT 304
#define LT 305
#define GTEQUAL 306
#define LTEQUAL 307
#define OPENSQUARE 308
#define CLOSESQUARE 309
#define BINARYPACKAGE 310
#define BUILDDEPENDS 311
#define STANDARDSVERSION 312
#define FORMAT 313
#define DIRECTORY 314
#define FILES 315




#ifndef YYSTYPE
typedef int yystype;
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_INIPARSE_HH */

